@@ -181,7 +181,10 @@ class ImagesController(object):
                          'expire': (expiry - age).total_seconds()})
         else:
             LOG.debug('Image %(image)s has import task %(task)s in status '
-                      '%(status)s and does not qualify for expiry.')
+                      '%(status)s and does not qualify for expiry.',
+                      {'image': image.image_id,
+                       'task': task.task_id,
+                       'status': task.status})
         raise exception.Conflict('Image has active task')
 
     def _cleanup_stale_task_progress(self, image_repo, image, task):
@@ -212,7 +215,6 @@ class ImagesController(object):
     def import_image(self, req, image_id, body):
         image_repo = self.gateway.get_repo(req.context)
         task_factory = self.gateway.get_task_factory(req.context)
-        executor_factory = self.gateway.get_task_executor_factory(req.context)
         task_repo = self.gateway.get_task_repo(req.context)
         import_method = body.get('method').get('name')
         uri = body.get('method').get('uri')
@@ -243,7 +245,14 @@ class ImagesController(object):
             if not getattr(image, 'disk_format', None):
                 msg = _("'disk_format' needs to be set before import")
                 raise exception.Conflict(msg)
-            if not authorization.is_image_mutable(req.context, image):
+
+            # NOTE(danms): For copy-image only, we check policy to decide
+            # if the user should be able to do this. Otherwise, we forbid
+            # the import if the user is not the owner.
+            if import_method == 'copy-image':
+                self.policy.enforce(req.context, 'copy_image',
+                                    dict(policy.ImageTarget(image)))
+            elif not authorization.is_image_mutable(req.context, image):
                 raise webob.exc.HTTPForbidden(
                     explanation=_("Operation not permitted"))
 
@@ -291,6 +300,8 @@ class ImagesController(object):
             raise webob.exc.HTTPConflict(explanation=e.msg)
         except exception.NotFound as e:
             raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except exception.Forbidden as e:
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
 
         if (not all_stores_must_succeed) and (not CONF.enabled_backends):
             msg = (_("All_stores_must_succeed can only be set with "
@@ -301,6 +312,17 @@ class ImagesController(object):
                       'import_req': body,
                       'backend': stores}
 
+        if import_method == 'copy-image':
+            # If this is a copy-image import and we passed the policy check,
+            # grab an admin context for the task so it can manipulate metadata
+            # as admin.
+            admin_context = req.context.elevated()
+        else:
+            admin_context = None
+
+        executor_factory = self.gateway.get_task_executor_factory(
+            req.context, admin_context=admin_context)
+
         if (import_method == 'web-download' and
                 not utils.validate_import_uri(uri)):
             LOG.debug("URI for web-download does not pass filtering: %s", uri)
@@ -332,8 +354,8 @@ class ImagesController(object):
 
             task_repo.add(import_task)
             task_executor = executor_factory.new_task_executor(req.context)
-            pool = common.get_thread_pool("tasks_eventlet_pool")
-            pool.spawn_n(import_task.run, task_executor)
+            pool = common.get_thread_pool("tasks_pool")
+            pool.spawn(import_task.run, task_executor)
         except exception.Forbidden as e:
             LOG.debug("User not permitted to create image import task.")
             raise webob.exc.HTTPForbidden(explanation=e.msg)
